feed-archiver 2.0.0b0 (2023-04-15)
==================================

Bugfixes
--------

- Restore correct versions going forward.  Versions from here to v1.0.0 below are
  incorrect. (correct-versions)

